/* Please read copyright.ncsa. Don't remove next line */
#include "../Copyrights/copyright.ncsa"

/* Created: Wed Apr 10 17:41:00 CDT 1996
 * Author: Dan Pape
 */

#ifndef __READJPEG_H__
#define __READJPEG_H__

unsigned char *ReadJPEG(FILE *infile,int *width, int *height, XColor *colrs);

#endif
